@@ -44,28 +44,42 @@ add_sector_and_borderline <- function(data) {
     check_classification(column = "sector_classification_direct_loantaker")
 
   out <- left_join(
-    checked, r2dii.data::sector_classifications,
+    checked, get_classifications(),
     by = set_names(c("code_system", "code"), crucial)
   )
 
   restore_typeof(data, out, crucial)
 }
 
+get_classifications <- function() {
+  custom_sector_classifications() %||% default_sector_classification()
+}
+
+default_sector_classification <- function() {
+  r2dii.data::sector_classifications
+}
+
+custom_sector_classifications <- function() {
+  getOption("r2dii.match.sector_classifications")
+}
+
 check_classification <- function(data,
                                  column,
+                                 # FIXME: Remove needless argument?
                                  classification = NULL) {
-  classification <- classification %||% r2dii.data::sector_classifications
+  classification <- classification %||% get_classifications()
   # To call columns from both data and classification with the same colname
   reference <- rename_as_loanbook(classification)
 
   all_unknown <- !any(data[[column]] %in% reference[[column]])
   known <- unique(reference[[column]])
-  if (all_unknown) {
+  if (all_unknown && is.null(custom_sector_classifications())) {
     abort_all_sec_classif_unknown(column, known)
   }
 
   unknown <- setdiff(unique(data[[column]]), reference[[column]])
   some_unknown <- !identical(unknown, character(0))
+
   if (some_unknown) {
     warn_some_sec_classif_unknown(column, unknown)
   }
